@@ -1,34 +1,5 @@
 use std::fs;
-use std::path::{Component, Path, PathBuf};
-
-// Removes the prefix of a path.
-//
-// If it begins with a root, it removes the root AND the desecendant of the root.
-
-fn remove_prefix<P>(from: P) -> PathBuf
-where
-    P: AsRef<Path>,
-{
-    let components = from.as_ref().components();
-    let mut add: bool = false; // When this is true, we have finisehd traversing the prefix and can continue adding stuff to our new components
-    let mut new_components = Vec::new();
-    for component in components {
-        if add {
-            new_components.push(component);
-        }
-        if component != Component::RootDir {
-            add = true;
-        }
-    }
-    new_components.iter().collect::<PathBuf>()
-}
-#[test]
-fn test_remove_prefix() {
-    assert_eq!(remove_prefix("foo/bar"), Path::new("bar"));
-    assert_eq!(remove_prefix("foo/bar/baz"), Path::new("bar/baz"));
-    assert_eq!(remove_prefix("/foo/bar"), Path::new("bar"));
-    assert_eq!(remove_prefix("/foo/bar/baz"), Path::new("bar/baz"));
-}
+use std::path::Path;
 
 /// Copies a directory into a destination directory,
 /// ignoring any "dotfiles" which begin with a `.`
@@ -66,10 +37,14 @@ where
     for entry in fs::read_dir(from)? {
         let entry = entry?;
         let path = &entry.path();
-        let destination = &to.join(remove_prefix(path));
+        let file_name = path.file_name().unwrap().to_str().unwrap();
+        if &file_name[..1] == "." {
+            return Ok(());
+        }
+        let destination = &to.join(file_name);
         if path.is_file() || path.is_symlink() {
             fs::copy(path, destination)
-                .expect(&format!("Failed to copy {:?} to {:?}", path, destination,));
+                .expect(&format!("Failed to copy {:?} to {:?}", path, destination));
         } else {
             if !destination.is_dir() {
                 if destination.exists() {
@@ -84,7 +59,7 @@ where
                     Ok(_) => {}
                 }
             }
-            copy_dir_ignore_dots(path, to)?
+            copy_dir_ignore_dots(path, destination)?
         }
     }
     Ok(())
